@@ -12,6 +12,7 @@ use Pcore::HTTP::Headers;
 use HTTP::Parser::XS qw[HEADERS_AS_ARRAYREF HEADERS_NONE];
 use Pcore::AE::Handle::Cache2;
 use Pcore::AE::Handle qw[:TLS_CTX];
+use Pcore::Util::Scalar qw[is_ref is_plain_arrayref];
 
 const our $PROXY_TYPE_HTTP    => 1;
 const our $PROXY_TYPE_CONNECT => 2;
@@ -1009,11 +1010,11 @@ sub store ( $self, $timeout = undef ) {
 sub get_connect ($connect) {
 
     # parse connect attribute
-    if ( ref $connect ne 'ARRAY' ) {
-        if ( !ref $connect ) {    # parse uri string
+    if ( !is_plain_arrayref $connect ) {
+        if ( !is_ref $connect ) {    # parse uri string
             $connect = P->uri( $connect, authority => 1 )->connect;
         }
-        else {                    # already uri object
+        else {                       # already uri object
             $connect = $connect->connect;
         }
     }
@@ -1037,30 +1038,30 @@ sub get_connect ($connect) {
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
 ## |    3 |                      | Subroutines::ProhibitExcessComplexity                                                                          |
-## |      | 73                   | * Subroutine "new" with high complexity score (47)                                                             |
-## |      | 671                  | * Subroutine "read_http_res_headers" with high complexity score (22)                                           |
-## |      | 797                  | * Subroutine "read_http_body" with high complexity score (29)                                                  |
+## |      | 74                   | * Subroutine "new" with high complexity score (47)                                                             |
+## |      | 672                  | * Subroutine "read_http_res_headers" with high complexity score (22)                                           |
+## |      | 798                  | * Subroutine "read_http_body" with high complexity score (29)                                                  |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 194                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 195                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 304, 707, 708        | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
+## |    3 | 305, 708, 709        | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 58, 491, 538, 543,   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
-## |      | 560, 606, 609, 612   |                                                                                                                |
+## |    2 | 59, 492, 539, 544,   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |      | 561, 607, 610, 613   |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 744                  | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
+## |    2 | 745                  | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    2 |                      | Documentation::RequirePodLinksIncludeText                                                                      |
-## |      | 1068                 | * Link L<AnyEvent::Handle> on line 1074 does not specify text                                                  |
-## |      | 1068                 | * Link L<AnyEvent::Handle> on line 1082 does not specify text                                                  |
-## |      | 1068                 | * Link L<AnyEvent::Handle> on line 1110 does not specify text                                                  |
-## |      | 1068                 | * Link L<AnyEvent::Handle> on line 1126 does not specify text                                                  |
-## |      | 1068                 | * Link L<AnyEvent::Socket> on line 1126 does not specify text                                                  |
-## |      | 1068, 1068           | * Link L<Pcore::Proxy> on line 1092 does not specify text                                                      |
-## |      | 1068                 | * Link L<Pcore::Proxy> on line 1126 does not specify text                                                      |
+## |      | 1069                 | * Link L<AnyEvent::Handle> on line 1075 does not specify text                                                  |
+## |      | 1069                 | * Link L<AnyEvent::Handle> on line 1083 does not specify text                                                  |
+## |      | 1069                 | * Link L<AnyEvent::Handle> on line 1111 does not specify text                                                  |
+## |      | 1069                 | * Link L<AnyEvent::Handle> on line 1127 does not specify text                                                  |
+## |      | 1069                 | * Link L<AnyEvent::Socket> on line 1127 does not specify text                                                  |
+## |      | 1069, 1069           | * Link L<Pcore::Proxy> on line 1093 does not specify text                                                      |
+## |      | 1069                 | * Link L<Pcore::Proxy> on line 1127 does not specify text                                                      |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 54, 59, 496, 606,    | CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              |
-## |      | 609, 612, 618        |                                                                                                                |
+## |    1 | 55, 60, 497, 607,    | CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              |
+## |      | 610, 613, 619        |                                                                                                                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
